@@ -1,20 +1,26 @@
-#define QT_FEATURE_android_style_assets -1
-
-#define QT_FEATURE_gc_binaries -1
-
 #define QT_FEATURE_use_bfd_linker -1
 
 #define QT_FEATURE_use_gold_linker -1
 
 #define QT_FEATURE_use_lld_linker -1
 
+#define QT_FEATURE_use_mold_linker -1
+
+#define QT_FEATURE_android_style_assets -1
+
+#define QT_FEATURE_gc_binaries -1
+
+#define QT_FEATURE_developer_build -1
+
 #define QT_FEATURE_private_tests -1
 
 #define QT_FEATURE_debug -1
 
 #define QT_FEATURE_reduce_exports 1
 
-#define QT_FEATURE_reduce_relocations -1
+#define QT_FEATURE_no_direct_extern_access -1
+
+#define QT_FEATURE_x86intrin -1
 
 #define QT_FEATURE_sse2 -1
 
@@ -50,8 +56,12 @@
 
 #define QT_FEATURE_avx512vbmi -1
 
+#define QT_FEATURE_avx512vbmi2 -1
+
 #define QT_FEATURE_aesni -1
 
+#define QT_FEATURE_vaes -1
+
 #define QT_FEATURE_rdrnd -1
 
 #define QT_FEATURE_rdseed -1
@@ -62,7 +72,7 @@
 
 #define QT_FEATURE_mips_dspr2 -1
 
-#define QT_FEATURE_neon -1
+#define QT_FEATURE_neon 1
 
 #define QT_FEATURE_arm_crc32 -1
 
@@ -80,7 +90,7 @@
 
 #define QT_FEATURE_system_zlib 1
 
-#define QT_FEATURE_zstd 1
+#define QT_FEATURE_stdlib_libcpp -1
 
 #define QT_FEATURE_dbus 1
 
@@ -102,6 +112,8 @@
 
 #define QT_FEATURE_libudev 1
 
+#define QT_FEATURE_openssl 1
+
 #define QT_FEATURE_dlopen 1
 
 #define QT_FEATURE_relocatable 1
